#ifndef _SERIAL_IO_H
#define _SERIAL_IO_H

#include <stdint.h>
#include <result.h>


#define SERIAL_TIMEOUT	5000 ///< Timeout value for serialRead() and serialWrite() in milliseconds


/**
* \brief Opens connection to the serial port and initializes it for raw IO.
* \param [in] strdev String defining the device to connect to
* \retval RES_OK	Connection established successfully
* \retval RES_FAIL	Conection failed
**/
RES_t serialOpen(char *strdev);

/**
* \brief Writes data to the serial port. Returns once all data has been sent or timed out.
* \param [in] buf Pointer to data to be sent
* \param [in] size Number of bytes to send
* \retval RES_OK	All data was sent successfully
* \retval RES_FAIL	Not all data was sent. Operation timed out
**/
RES_t serialWrite(void *buf, size_t size);

/**
* \brief Writes data to the serial port. Returns once all data has been sent or timed out.
* \param [out] buf Pointer to destination buffer
* \param [in] size Number of bytes to receive
* \retval RES_OK	Requestred number of bytes were received
* \retval RES_FAIL	Not all data was received. Operation timed out
**/
RES_t serialRead(void *buf, size_t size);

/**
* \brief Discards any data in the input buffer.
* \return Nothing
**/
void serialFlushInput(void);

/**
* \brief Closes the connection to the serial port
* \retval RES_OK
**/
RES_t serialClose(void);

#endif

